
; PIC16F886 Configuration Bit Settings

; Assembly source line config statements

; CONFIG1
  CONFIG  FOSC = INTRC_NOCLKOUT ; Oscillator Selection bits (INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN)
  CONFIG  WDTE = OFF            ; Watchdog Timer Enable bit (WDT disabled and can be enabled by SWDTEN bit of the WDTCON register)
  CONFIG  PWRTE = OFF           ; Power-up Timer Enable bit (PWRT disabled)
  CONFIG  MCLRE = ON            ; RE3/MCLR pin function select bit (RE3/MCLR pin function is MCLR)
  CONFIG  CP = OFF              ; Code Protection bit (Program memory code protection is disabled)
  CONFIG  CPD = OFF             ; Data Code Protection bit (Data memory code protection is disabled)
  CONFIG  BOREN = OFF           ; Brown Out Reset Selection bits (BOR disabled)
  CONFIG  IESO = OFF            ; Internal External Switchover bit (Internal/External Switchover mode is disabled)
  CONFIG  FCMEN = OFF           ; Fail-Safe Clock Monitor Enabled bit (Fail-Safe Clock Monitor is disabled)
  CONFIG  LVP = OFF             ; Low Voltage Programming Enable bit (RB3 pin has digital I/O, HV on MCLR must be used for programming)

; CONFIG2
  CONFIG  BOR4V = BOR40V        ; Brown-out Reset Selection bit (Brown-out Reset set to 4.0V)
  CONFIG  WRT = OFF             ; Flash Program Memory Self Write Enable bits (Write protection off)

// config statements should precede project file includes.
#include <xc.inc>



PSECT BLABLA, CLASS=CODE, DELTA=2, ABS

#define LED1 RC0
  #define LED2 RC1
  #define LED3 RC2
  #define LED4 RC3
  #define LED5 RC4
  #define LED6 RC5
  #define LED7 RC6
  #define LED8 RC7
  
  #define PB1	RB0
  #define PB2	RB1
  #define PB3	RB2
  #define PB4	RB3
  #define PB5	RB4
  #define PB6	RB5
  #define PB7	RB6
  #define PB8	RB7
		
#define BUZZER RA5
COUNTER EQU 0X20
 
 
DCounter1 EQU 0X70
DCounter2 EQU 0X71
DCounter3 EQU 0X72
  
  ORG	    0X000
  GOTO	    MAIN
  
  
  MAIN:
    CALL    SETUP
    CALL    CHECK_SYSTEM
 REP:   
    BTFSS   PB1
    CALL    USER1
    
    BTFSS   PB2
    CALL    USER2
    
    BTFSS   PB3
    CALL    USER3
    
    BTFSS   PB4
    CALL    USER4
    
    BTFSS   PB5
    CALL    USER5
    
    BTFSS   PB6
    CALL    USER6
    
    BTFSS   PB7
    CALL    USER7
  
    BTFSS   PB8
    CALL    USER8
    
    GOTO    REP
  
    
USER1:
    BSF	    LED1
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED1
    CALL    DELAY_100MS
    BCF	    LED1
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
 USER2:
    BSF	    LED2
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED2
    CALL    DELAY_100MS
    BCF	    LED2
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
  
USER3:
    BSF	    LED3
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED3
    CALL    DELAY_100MS
    BCF	    LED3
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
USER4:
    BSF	    LED4
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED4
    CALL    DELAY_100MS
    BCF	    LED4
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
     USER5:
        BSF	    LED5
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED5
    CALL    DELAY_100MS
    BCF	    LED5
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
     USER6:
        BSF	    LED6
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED6
    CALL    DELAY_100MS
    BCF	    LED6
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
     USER7:
        BSF	    LED7
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED7
    CALL    DELAY_100MS
    BCF	    LED7
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
     USER8:
        BSF	    LED8
    BSF	    BUZZER
    CALL    DELAY_1S
    BCF	    BUZZER
    
    
    MOVLW   10
    MOVWF   COUNTER 
    BSF	    LED8
    CALL    DELAY_100MS
    BCF	    LED8
    CALL    DELAY_100MS
    DECFSZ  COUNTER ,F
    GOTO    $-5
    RETURN
    
    
CHECK_SYSTEM:
    MOVLW   11111111B
    MOVWF   PORTC
    
    BSF	    BUZZER
    CALL    DELAY_1S
    
    CLRF    PORTC
    BCF	    BUZZER
    
    RETURN
    
    
    
SETUP:
    CLRF    PORTA
    CLRF    PORTB
    CLRF    PORTC
    
    BSF	    RP0
    BCF	    RP1
    MOVLW   01100000B
    MOVWF   OSCCON
    
    CLRF    TRISC
    MOVLW   11111111B
    MOVWF   TRISB
    
    CLRF    TRISA
    BSF	    RP1
    CLRF    ANSEL
    CLRF    ANSELH
    
    BCF	    RP0
    BCF	    RP1
    RETURN

DELAY_1S:
MOVLW 0Xac
MOVWF DCounter1
MOVLW 0X13
MOVWF DCounter2
MOVLW 0X06
MOVWF DCounter3

DECFSZ DCounter1, 1
GOTO $-1
DECFSZ DCounter2, 1
GOTO $-3
DECFSZ DCounter3, 1
GOTO $-5
NOP
RETURN


DELAY_100MS:
MOVLW 0Xdc
MOVWF DCounter1
MOVLW 0X82
MOVWF DCounter2

DECFSZ DCounter1, 1
GOTO $-1
DECFSZ DCounter2, 1
GOTO $-3
NOP
RETURN
